Module neos_common.api
======================

Functions
---------

`get_error_codes(module_names: str | list[str]) ‑> neos_common.schema.ErrorCodes`
:   Get all error codes and messages from the error module.

`get_permissions(app: fastapi.applications.FastAPI, ignore_routes: list[str] | None = None) ‑> neos_common.schema.FormattedRoutes`
: